@@ -1,7 +1,8 @@
 from . common import Table
-from . columns import Column, MergeColumn, ActionColumn
+from . columns import Column, MergeColumn, ButtonColumn, ActionColumn
 
 __all__ = ["Table",
            "Column",
            "MergeColumn",
+           "ButtonColumn",
            "ActionColumn"]
